'use strict';

exports.__esModule = true;

require('isomorphic-fetch');

var _errors = require('./errors.js');

// TODO: Search how to make json parsing error identifiable.
var createFetcher = function createFetcher(path) {
    return function (request) {
        return fetch(path, {
            method: 'POST',
            headers: {
                Accept: 'application/json',
                'Content-Type': 'application/json'
            },
            credentials: 'include',
            body: JSON.stringify({
                query: request
            })
        }).then(function (response) {
            var contentType = response.headers.get("content-type");
            if (contentType && contentType.indexOf("application/json") !== -1) {
                return response.json();
            } else {
                return Promise.reject(new _errors.JsonParsingError("graphl response is not a valid json object", JSON.stringify(response)));
            }
        }).catch(function (e) {
            if (e instanceof _errors.JsonParsingError) {
                return Promise.reject(e);
            } else {
                return Promise.reject(new _errors.ServerError('Server issue', e));
            }
        });
    };
};

exports.default = createFetcher;