import 'isomorphic-fetch';
import {ServerError, JsonParsingError} from './errors.js';

// TODO: Search how to make json parsing error identifiable.
const createFetcher = path => request =>
    fetch(path, {
        method: 'POST',
        headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json'
        },
        credentials: 'include',
        body: JSON.stringify({
            query: request
        })
    })
    .then(response => {
        var contentType = response.headers.get("content-type");
        if(contentType && contentType.indexOf("application/json") !== -1) {
            return response.json();
        } else {
            return Promise.reject(new JsonParsingError("graphl response is not a valid json object", JSON.stringify(response)));
        }
    })
    .catch(e => {
        if(e instanceof JsonParsingError) {
            return Promise.reject(e);
        } else {
            return Promise.reject(new ServerError('Server issue', e));
        }
    })

export default createFetcher;
